<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../radialMap/map.cpp" line="108"/>
        <source>%1 files</source>
        <translation>%1 archivos</translation>
    </message>
    <message numerus="yes">
        <location filename="../../radialMap/map.cpp" line="204"/>
        <source>%n file(s), with an average size of %1</source>
        <comment>file</comment>
        <translation>
            <numerusform>%n archivo, con un tamaño promedio de %1</numerusform>
            <numerusform>%n archivos, con un tamaño promedio de %1</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RadialMap::Widget</name>
    <message numerus="yes">
        <location filename="../../radialMap/widgetEvents.cpp" line="194"/>
        <location filename="../../radialMap/widgetEvents.cpp" line="196"/>
        <source> into %n file(s)</source>
        <comment>file</comment>
        <translation>
            <numerusform> en %n archivo</numerusform>
            <numerusform> en %n archivos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="293"/>
        <location filename="../../interface.cpp" line="314"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Comprar la versión Ultimate para financiar el desarrollo</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="293"/>
        <location filename="../../interface.cpp" line="314"/>
        <source>Register your key</source>
        <translation>Registra tu clave</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="525"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>Archivo %1/%2, el tamaño: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="832"/>
        <source>Copy list</source>
        <translation>Lista de copia</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="834"/>
        <source>Move list</source>
        <translation>Lista de movimiento</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1335"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>No cierre si se encuentran errores</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1336"/>
        <source>Never close</source>
        <translation>Nunca cierre</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1337"/>
        <source>Always close</source>
        <translation>Siempre cerrar</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1339"/>
        <source>File Name, 0KB</source>
        <translation>Nombre de archivo, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1549"/>
        <location filename="../../interface.cpp" line="1561"/>
        <location filename="../../interface.cpp" line="1573"/>
        <source>Select a color</source>
        <translation>Seleccione un color</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1661"/>
        <location filename="../../interface.cpp" line="1672"/>
        <location filename="../../interface.cpp" line="1681"/>
        <source>%1 %2% of %3 into %4 files</source>
        <translation>%1 %2% de %3 en %4 archivos</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="320"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>No cierre si se encuentran errores</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="321"/>
        <source>Never close</source>
        <translation>Nunca cierre</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="322"/>
        <source>Always close</source>
        <translation>Siempre cerrar</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="518"/>
        <location filename="../../ThemesFactory.cpp" line="533"/>
        <location filename="../../ThemesFactory.cpp" line="548"/>
        <source>Select a color</source>
        <translation>Seleccione un color</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="420"/>
        <source>From:</source>
        <translation>De:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="301"/>
        <source>&amp;More</source>
        <translation>&amp;Más</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="321"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="482"/>
        <source>&amp;Skip</source>
        <translation>&amp;Omitir</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="493"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="389"/>
        <source>Close on transfer completion</source>
        <translation>Cerca de finalización de transferencia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="232"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="252"/>
        <source>100MB+</source>
        <translation>100MB+</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="527"/>
        <source>Limit copy speed to:</source>
        <translation>Limitar la velocidad de copia en:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="570"/>
        <source>Transfer list</source>
        <translation>Lista de transferencia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="593"/>
        <source>Move the selected items to the top</source>
        <translation>Mueve los elementos seleccionados a la parte superior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="619"/>
        <source>Move up the selected items</source>
        <translation>Mueva los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="645"/>
        <source>Move down the selected items</source>
        <translation>Bajar los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="671"/>
        <source>Move the selected items to the bottom</source>
        <translation>Mueve los elementos seleccionados a la parte inferior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="697"/>
        <source>Add file/folder</source>
        <translation>Agregar archivo/carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="726"/>
        <source>Delete the selected items</source>
        <translation>Eliminar los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="752"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="781"/>
        <source>Export the transfer list</source>
        <translation>Exportar la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="807"/>
        <source>Import the transfer list</source>
        <translation>Importe la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="862"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="869"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="904"/>
        <location filename="../../interface.ui" line="973"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="924"/>
        <source>Export the errors into transfer list</source>
        <translation>Exportar los errores en la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="963"/>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="968"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="982"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1028"/>
        <source>Add file</source>
        <translation>Añadir archivo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1037"/>
        <source>Add folder</source>
        <translation>Añadir carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1046"/>
        <source>Move file(s)</source>
        <translation>Mover archivo(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1055"/>
        <source>Move folder</source>
        <translation>Mueva la carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1064"/>
        <source>Copy file(s)</source>
        <translation>Copia el archivo(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1073"/>
        <source>Copy folder</source>
        <translation>Copia la carpeta</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="293"/>
        <source>Show dual progression</source>
        <translation>Mostrar progresión dual</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="245"/>
        <source>Show speed as main information</source>
        <translation>Mostrar la velocidad como principales informaciones</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Uso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="110"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Comience con el &quot;botón más&quot; empujada</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="57"/>
        <source>Minimize on close to systray</source>
        <translation>Minimizar en cerca de la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="80"/>
        <source>At the end of the copy</source>
        <translation>Al final de la copia</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="70"/>
        <location filename="../../themesOptions.ui" line="87"/>
        <source>Limit copy speed to</source>
        <translation>Limitar la velocidad de copia de</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="117"/>
        <source>Start minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="144"/>
        <source>Position at start</source>
        <translation>Posición al inicio</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="239"/>
        <source>Information</source>
        <translation>Informacións</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="332"/>
        <source>Click to edit the color</source>
        <translation>Haga clic para editar el color</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="97"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="204"/>
        <source>Dark UI</source>
        <translation>Interfaz de usuario oscura</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="212"/>
        <source>Default</source>
        <translation>Defecto</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="217"/>
        <source>Save as previous</source>
        <translation>Guardar como anterior</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="222"/>
        <source>At Center</source>
        <translation>En el centro</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Display</source>
        <translation>Visualización</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="283"/>
        <source>Speed with progress bar</source>
        <translation>Velocidad con barra de progreso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="313"/>
        <source>Progression color</source>
        <translation>Progresión de color</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="303"/>
        <source>Show progression in the title</source>
        <translation>Mostrar progresión en el título</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Always on top</source>
        <translation>Siempre visible</translation>
    </message>
</context>
</TS>
